@@ -10,6 +10,7 @@
 //---------------------------------------------------------------------------
 #include <string>
 #include <vector>
+#include <utility>
 #include "MediaInfo/MediaInfo.h"
 #include "Common/MediaConchLib.h"
 
@@ -34,19 +35,30 @@ namespace MediaConch
         void set_report_reset();
         int  set_format(MediaConchLib::format f);
         int  set_format(const std::string& f);
-        void add_policy(const std::string& policy);
+        int  add_policy(const std::string& filename);
         void set_display_file(const std::string& file);
-        int  register_option(const std::string& opt);
+        int  register_option(const std::string& opt, std::string& value);
         void set_use_daemon(bool use) { use_daemon = use; }
         void set_configuration_file(const std::string& file);
         void set_plugins_configuration_file(const std::string& file);
         void set_implementation_schema_file(const std::string& file);
         void set_implementation_verbosity(const std::string& verbosity);
+        int  set_policy_reference_file(const std::string& file);
+        int  add_plugin_to_use(const std::string& plugin);
+        int  set_user_to_use(const std::string& user);
         int  set_compression_mode(const std::string& mode_str);
         void set_force_analyze(bool force);
+        void set_mil_analyze(bool analyze);
         void set_asynchronous(bool async);
         void set_create_policy_mode();
+        void set_file_information_mode();
+        void set_plugins_list_mode();
         int  get_values_for_type_field(const std::string& type, const std::string& field, std::vector<std::string>& values);
+        int  set_watch_folder(const std::string& folder);
+        int  set_watch_folder_reports(const std::string& folder);
+        int  set_watch_folder_not_recursive();
+        int  set_watch_folder_user(const std::string& user);
+        void set_list_watch_folders_mode();
 
         void print_error(MediaConchLib::errorHttp code);
 
@@ -54,23 +66,43 @@ namespace MediaConch
         CLI(const CLI&);
         CLI& operator=(const CLI&);
 
-        int  run_create_policy();
-        int  is_ready(size_t i, MediaConchLib::report& report_kind);
+        int  run_create_policy(const std::vector<long>& files_ids);
+        int  run_policy_reference_file(long file_id);
+        int  run_file_information();
+        int  run_plugins_list();
+        int  run_watch_folders_list();
+        int  run_watch_folder_cmd();
+        int  is_ready(long& file_id, MediaConchLib::report& report_kind);
         void add_files_recursively(const std::string& filename);
+        void file_info_report(const MediaConchLib::Checker_FileInfo* info, std::string& report);
 
         MediaConchLib MCL;
         std::vector<std::string> files;
         std::vector<std::string> policies;
+        std::vector<std::string> plugins;
+        std::vector<std::pair<std::string,std::string> > options;
         std::string              error;
         std::string              display_file;
         std::string              configuration_file;
         std::string              plugins_configuration_file;
+        std::string              policy_reference_file;
+        std::string              watch_folder;
+        std::string              watch_folder_reports;
+        long                    *watch_folder_user;
         std::bitset<MediaConchLib::report_Max> report_set;
         MediaConchLib::format   format;
+        //TODO: clean
+        long                    use_as_user;
         bool                    use_daemon;
         bool                    asynchronous;
         bool                    force_analyze;
+        bool                    mil_analyze;
+        bool                    watch_folder_recursive;
         bool                    create_policy_mode;
+        bool                    file_information;
+        bool                    plugins_list_mode;
+        bool                    list_watch_folders_mode;
+        bool                    no_needs_files_mode;
     };
 
 }
