@@ -52,31 +52,66 @@ static bool wait_for_another_argument(std::string& argument)
         Last_Argument = "--pluginsconfiguration=";
         return true;
     }
-    if (argument=="-p")
+    else if (argument=="-p")
     {
         Last_Argument = "--policy=";
         return true;
     }
-    if (argument=="-d")
+    else if (argument=="-d")
     {
         Last_Argument = "--display=";
         return true;
     }
-    if (argument=="-c")
+    else if (argument=="-c")
     {
         Last_Argument = "--configuration=";
         return true;
     }
-    if (argument=="-i")
+    else if (argument=="-i")
     {
         Last_Argument = "--implementationschema=";
         return true;
     }
-    if (argument=="-iv")
+    else if (argument=="-iv")
     {
         Last_Argument = "--implementationverbosity=";
         return true;
     }
+    else if (argument=="-prf")
+    {
+        Last_Argument = "--policyreferencefile=";
+        return true;
+    }
+    else if (argument=="-up")
+    {
+        Last_Argument = "--useplugin=";
+        return true;
+    }
+    else if (argument=="-u")
+    {
+        Last_Argument = "--user=";
+        return true;
+    }
+    else if (argument=="-wfl")
+    {
+        Last_Argument = "--watchfolders-list=";
+        return true;
+    }
+    else if (argument=="-wf")
+    {
+        Last_Argument = "--watchfolder=";
+        return true;
+    }
+    else if (argument=="-wfr")
+    {
+        Last_Argument = "--watchfolder-reports=";
+        return true;
+    }
+    else if (argument=="-wfu")
+    {
+        Last_Argument = "--watchfolder-user=";
+        return true;
+    }
     return false;
 }
 
@@ -89,6 +124,8 @@ static void change_short_options_to_long(std::string& argument)
         argument = "--version";
     if (argument=="-f")
         argument = "--force";
+    if (argument=="-nmil")
+        argument = "--nomilanalyze";
 
     // Backward compatibility
     if (argument=="-tc")
@@ -105,6 +142,8 @@ static void change_short_options_to_long(std::string& argument)
         argument = "-mi";
     if (argument=="--mediatrace")
         argument = "-mt";
+    if (argument=="--micromediatrace")
+        argument = "-mmt";
 
     // Report short options
     if (argument=="-mc")
@@ -113,6 +152,8 @@ static void change_short_options_to_long(std::string& argument)
         argument = "--report=MediaInfo";
     if (argument=="-mt")
         argument = "--report=MediaTrace";
+    if (argument=="-mmt")
+        argument = "--report=MicroMediaTrace";
 
     // Format short options
     if (argument=="-ft")
@@ -133,6 +174,13 @@ static void change_short_options_to_long(std::string& argument)
     // Asynchronous mode
     if (argument=="-as")
         argument = "--async=yes";
+
+    if (argument=="-fi")
+        argument = "--fileinformation";
+
+    // Watch Folder short options
+    if (argument=="-wfnr")
+        argument = "--watchfolder-not-recursive";
 }
 
 int Parse(MediaConch::CLI* cli, std::string& argument)
@@ -163,6 +211,7 @@ int Parse(MediaConch::CLI* cli, std::string& argument)
     OPTION("--version",                                     Version)
     OPTION("--report",                                      Report)
     OPTION("--format",                                      Format)
+    OPTION("--policyreferencefile",                         PolicyReferenceFile)
     OPTION("--policy",                                      PolicyOption)
     OPTION("--display",                                     Display)
     OPTION("--logfile",                                     LogFile)
@@ -171,10 +220,20 @@ int Parse(MediaConch::CLI* cli, std::string& argument)
     OPTION("--implementationverbosity",                     ImplementationVerbosity)
     OPTION("--compression",                                 Compression)
     OPTION("--force",                                       Force)
+    OPTION("--nomilanalyze",                                NoMilAnalyze)
     OPTION("--async",                                       Asynchronous)
+    OPTION("--pluginslist",                                 PluginsList)
+    OPTION("--useplugin",                                   UsePlugin)
     OPTION("--pluginsconfiguration",                        PluginsConfiguration)
     OPTION("--defaultvaluesfortype",                        DefaultValuesForType)
     OPTION("--createpolicy",                                CreatePolicy)
+    OPTION("--fileinformation",                             FileInformation)
+    OPTION("--watchfolders-list",                           WatchFoldersList)
+    OPTION("--watchfolder-reports",                         WatchFolderReports)
+    OPTION("--watchfolder-not-recursive",                   WatchFolderNotRecursive)
+    OPTION("--watchfolder-user",                            WatchFolderUser)
+    OPTION("--watchfolder",                                 WatchFolder)
+    OPTION("--user",                                        User)
     //Default
     OPTION("--",                                            Default)
     else
@@ -345,6 +404,23 @@ CL_OPTION(ImplementationVerbosity)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(PolicyReferenceFile)
+{
+    //Form : --PolicyReferenceFile=File
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string file;
+    file.assign(argument, egal_pos + 1 , std::string::npos);
+    cli->set_policy_reference_file(file);
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(Compression)
 {
@@ -371,6 +447,14 @@ CL_OPTION(Force)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(NoMilAnalyze)
+{
+    (void)argument;
+    cli->set_mil_analyze(false);
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(Asynchronous)
 {
@@ -391,6 +475,33 @@ CL_OPTION(Asynchronous)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(UsePlugin)
+{
+    //Form : --UsePlugin=IdPlugin
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string plugin;
+    plugin.assign(argument, egal_pos + 1 , std::string::npos);
+
+    cli->add_plugin_to_use(plugin);
+    return CLI_RETURN_NONE;
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(PluginsList)
+{
+    //Form : --PluginsList
+    (void)argument;
+    cli->set_plugins_list_mode();
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(PluginsConfiguration)
 {
@@ -457,10 +568,125 @@ CL_OPTION(CreatePolicy)
     return CLI_RETURN_NONE;
 }
 
+//---------------------------------------------------------------------------
+CL_OPTION(FileInformation)
+{
+    //Form : --FileInformation, -fi
+    (void)argument;
+    cli->set_file_information_mode();
+
+    return CLI_RETURN_NONE;
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(WatchFoldersList)
+{
+    //Form : --WatchFoldersList
+    (void)argument;
+    cli->set_list_watch_folders_mode();
+
+    return CLI_RETURN_NONE;
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(WatchFolder)
+{
+    //Form : --WatchFolder=folder, -wf folder
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string folder;
+    folder.assign(argument, egal_pos + 1 , std::string::npos);
+    cli->set_watch_folder(folder);
+
+    return CLI_RETURN_NONE;
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(WatchFolderReports)
+{
+    //Form : --WatchFolderReports=folder, -wfr folder
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string folder;
+    folder.assign(argument, egal_pos + 1 , std::string::npos);
+    cli->set_watch_folder_reports(folder);
+
+    return CLI_RETURN_NONE;
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(WatchFolderNotRecursive)
+{
+    //Form : --WatchFolderNotRecursive, -wfnr
+    (void)argument;
+    return cli->set_watch_folder_not_recursive();
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(WatchFolderUser)
+{
+    //Form : --WatchFolderUser=user, -wfu user
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string user;
+    user.assign(argument, egal_pos + 1 , std::string::npos);
+    cli->set_watch_folder_user(user);
+
+    return CLI_RETURN_NONE;
+}
+
+//---------------------------------------------------------------------------
+CL_OPTION(User)
+{
+    //Form : --User=user, -u user
+    size_t egal_pos = argument.find('=');
+    if (egal_pos == std::string::npos)
+    {
+        Help();
+        return CLI_RETURN_ERROR;
+    }
+
+    std::string user;
+    user.assign(argument, egal_pos + 1 , std::string::npos);
+    cli->set_user_to_use(user);
+
+    return CLI_RETURN_NONE;
+}
+
 //---------------------------------------------------------------------------
 CL_OPTION(Default)
 {
-    return cli->register_option(argument);
+    //Form : --Option=Value, --Option
+
+    if (argument.size() < 2)
+        return CLI_RETURN_NONE;
+
+    std::string key, value;
+    size_t egal_pos = argument.find('=');
+    if (egal_pos != std::string::npos)
+    {
+        key.assign(argument, 2, egal_pos - 2);
+        value.assign(argument, egal_pos + 1 , std::string::npos);
+    }
+    else
+        key.assign(argument, 2, std::string::npos);
+
+    return cli->register_option(key, value);
 }
 
 //---------------------------------------------------------------------------
@@ -479,8 +705,9 @@ void CallBack_Set(MediaConch::CLI* cli, void* Event_CallBackFunction)
 {
     //CallBack configuration
     std::stringstream callback_mem;
-    callback_mem << "--Event_CallBackFunction=";
     callback_mem << "CallBack=memory://";
     callback_mem << (size_t)Event_CallBackFunction;
-    cli->register_option(callback_mem.str());
+
+    std::string value = callback_mem.str();
+    cli->register_option("Event_CallBackFunction", value);
 }
