@@ -87,4 +87,38 @@ void DatabaseReport::get_sql_query_for_update_report_table_v2(std::string& q)
     q = create.str();
 }
 
+//---------------------------------------------------------------------------
+void DatabaseReport::get_sql_query_for_update_report_table_v3(std::string& q)
+{
+    std::stringstream create;
+    create << "CREATE TABLE IF NOT EXISTS MEDIACONCH_FILE ";
+    create << "(ID INTEGER PRIMARY KEY ASC,";
+    create << " USER INT DEFAULT -1,";
+    create << " FILENAME TEXT NOT NULL,";
+    create << " FILE_LAST_MODIFICATION TEXT NOT NULL,";
+
+    create << " ANALYZED INT DEFAULT 0,";
+
+    create << " HAS_ERROR INT DEFAULT 0,";
+    create << " ERROR_LOG TEXT,";
+
+    create << " GENERATED_ID INT DEFAULT -1,";
+
+    create << " SOURCE_ID INT DEFAULT -1,";
+    create << " GENERATED_TIME INT DEFAULT -1,";
+    create << " GENERATED_LOG TEXT,";
+    create << " GENERATED_ERROR_LOG TEXT);";
+
+    create << " CREATE TABLE IF NOT EXISTS MEDIACONCH_REPORT ";
+    create << "(FILE_ID INT NOT NULL,";
+    create << " TOOL INT NOT NULL,";
+    create << " FORMAT INT NOT NULL,";
+    create << " COMPRESS INT DEFAULT 0 NOT NULL,";
+    create << " MIL_VERSION INT DEFAULT 0 NOT NULL,";
+    create << " REPORT TEXT);";
+
+    create << " DROP TABLE Report;";
+    q = create.str();
+}
+
 }
