@@ -47,9 +47,10 @@ protected:
     sqlite3_stmt                                    *stmt; // Statement handler
 
     // Helper
-    int std_string_to_int(const std::string& str);
-    int get_db_version(int& version);
-    int set_db_version(int version);
+    long std_string_to_int(const std::string& str);
+    size_t std_string_to_uint(const std::string& str);
+    int  get_db_version(int& version);
+    int  set_db_version(int version);
     const std::string& get_error() const;
 
     SQLLite (const SQLLite&);
