@@ -5,7 +5,7 @@
  */
 
 #include "Common/Policy.h"
-#include "Common/ImplementationReportDisplayHtmlXsl.h"
+#include "Common/generated/ImplementationReportDisplayHtmlXsl.h"
 #include "mainwindow.h"
 #include "checkerwindow.h"
 #include "ui_mainwindow.h"
@@ -213,28 +213,32 @@ void CheckerWindow::hide()
 //---------------------------------------------------------------------------
 void CheckerWindow::create_policy_options(QString& policies)
 {
-    const std::vector<Policy *>& list = mainwindow->get_all_policies();
+    MediaConchLib::Get_Policies list;
+    mainwindow->get_policies("JSON", list);
 
     QString system_policy;
     QString user_policy;
     int selected_policy = mainwindow->select_correct_policy();
-    for (size_t i = 0; i < list.size(); ++i)
+    for (size_t i = 0; list.policies && i < list.policies->size(); ++i)
     {
-        if (list[i]->filename.length() && list[i]->filename.find(":/") == 0)
+        if (!list.policies->at(i))
+            continue;
+
+        if (list.policies->at(i)->is_system)
         {
             system_policy += QString("<option ");
-            if ((int)i == selected_policy)
+            if ((int)list.policies->at(i)->id == selected_policy)
                 system_policy += QString("selected=\"selected\" ");
             system_policy += QString("value=\"%1\">%2</option>")
-                .arg((int)i).arg(QString().fromUtf8(list[i]->title.c_str(), list[i]->title.length()));
+                .arg(list.policies->at(i)->id).arg(QString().fromUtf8(list.policies->at(i)->name.c_str(), list.policies->at(i)->name.length()));
         }
         else
         {
             user_policy += QString("<option ");
-            if ((int)i == selected_policy)
+            if ((int)list.policies->at(i)->id == selected_policy)
                 user_policy += QString("selected=\"selected\" ");
             user_policy += QString("value=\"%1\">%2</option>")
-                .arg((int)i).arg(QString().fromUtf8(list[i]->title.c_str(), list[i]->title.length()));
+                .arg(list.policies->at(i)->id).arg(QString().fromUtf8(list.policies->at(i)->name.c_str(), list.policies->at(i)->name.length()));
         }
     }
 
