@@ -75,6 +75,59 @@ FileRegistered* WorkerFiles::get_file_registered_from_file(const std::string& fi
     return fr;
 }
 
+//---------------------------------------------------------------------------
+FileRegistered* WorkerFiles::get_file_registered_from_id(long id)
+{
+    FileRegistered* fr = NULL;
+    working_files_mutex.lock();
+    std::map<std::string, FileRegistered*>::iterator it = working_files.begin();
+    for (; it != working_files.end(); ++it)
+    {
+        if (!it->second)
+            continue;
+
+        if (it->second->file_id == id)
+        {
+            fr = new FileRegistered(*it->second);
+            break;
+        }
+    }
+    working_files_mutex.unlock();
+    return fr;
+}
+
+//---------------------------------------------------------------------------
+long WorkerFiles::get_id_from_registered_file(const std::string& file)
+{
+    long id = -1;
+    working_files_mutex.lock();
+    if (working_files.find(file) != working_files.end() && working_files[file])
+        id = working_files[file]->file_id;
+    working_files_mutex.unlock();
+    return id;
+}
+
+//---------------------------------------------------------------------------
+std::string WorkerFiles::get_filename_from_registered_file_id(long file_id)
+{
+    std::string filename;
+    working_files_mutex.lock();
+    std::map<std::string, FileRegistered*>::iterator it = working_files.begin();
+    for (; it != working_files.end(); ++it)
+    {
+        if (!it->second)
+            continue;
+
+        if (it->second->file_id == file_id)
+        {
+            filename = it->second->filename;
+            break;
+        }
+    }
+    working_files_mutex.unlock();
+    return filename;
+}
+
 //---------------------------------------------------------------------------
 void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered>& files)
 {
@@ -92,7 +145,7 @@ void WorkerFiles::get_registered_files(std::map<std::string, FileRegistered>& fi
 
 //---------------------------------------------------------------------------
 void WorkerFiles::add_file_to_list(const std::string& file, const std::string& path,
-                                   int policy, int display, int verbosity)
+                                   int policy, int display, int verbosity, bool fixer)
 {
     std::string full_file(path);
     if (path.length())
@@ -106,7 +159,7 @@ void WorkerFiles::add_file_to_list(const std::string& file, const std::string& p
     {
         exists = true;
         // nothing to do
-        if (policy == working_files[full_file]->policy && display == working_files[full_file]->display
+        if (!fixer && policy == working_files[full_file]->policy && display == working_files[full_file]->display
             && verbosity == working_files[full_file]->verbosity)
         {
             working_files_mutex.unlock();
@@ -121,9 +174,13 @@ void WorkerFiles::add_file_to_list(const std::string& file, const std::string& p
 
     // Keep the old index for the same file
     if (exists)
+    {
         fr->index = working_files[full_file]->index;
+        fr->file_id = working_files[full_file]->file_id;
+    }
     else
         fr->index = file_index++;
+
     fr->filename = file;
     fr->filepath = path;
     fr->policy = policy;
@@ -141,7 +198,7 @@ void WorkerFiles::add_file_to_list(const std::string& file, const std::string& p
     unfinished_files.push_back(full_file);
     unfinished_files_mutex.unlock();
 
-    if (exists)
+    if (!fixer && exists)
     {
         to_update_files_mutex.lock();
         to_update_files[full_file] = new FileRegistered(*fr);
@@ -149,57 +206,72 @@ void WorkerFiles::add_file_to_list(const std::string& file, const std::string& p
         return;
     }
 
-    to_add_files_mutex.lock();
-    to_add_files[full_file] = new FileRegistered(*fr);
-    to_add_files_mutex.unlock();
-
     std::vector<std::string> vec;
     vec.push_back(full_file);
 
     int ret;
-    if ((ret = mainwindow->analyze(vec)) < 0)
+    std::vector<long> files_id;
+    if ((ret = mainwindow->analyze(vec, fixer, files_id)) < 0 || files_id.size() != 1)
         mainwindow->set_error_http((MediaConchLib::errorHttp)ret);
+
+    fr->file_id = files_id[0];
+
+    to_add_files_mutex.lock();
+    to_add_files[full_file] = new FileRegistered(*fr);
+    to_add_files_mutex.unlock();
+
+    working_files_mutex.lock();
+    working_files[full_file]->file_id = files_id[0];
+    working_files_mutex.unlock();
 }
 
 //---------------------------------------------------------------------------
-void WorkerFiles::update_policy_of_file_registered_from_file(const std::string& file, int policy)
+void WorkerFiles::update_policy_of_file_registered_from_file(long file_id, int policy)
 {
+    std::string file;
     working_files_mutex.lock();
-    if (working_files.find(file) == working_files.end() || !working_files[file])
+    std::map<std::string, FileRegistered*>::iterator it = working_files.begin();
+    for (; it != working_files.end(); ++it)
+    {
+        if (!it->second || it->second->file_id != file_id)
+            continue;
+
+        file = it->first;
+        break;
+    }
+
+    if (!file.size())
     {
         // file is not existing
         working_files_mutex.unlock();
         return;
     }
 
+    working_files[file]->policy = policy;
+
     bool policy_valid = false;
-    if (working_files[file]->analyzed && working_files[file]->report_kind == MediaConchLib::report_MediaConch && policy >= 0)
+    if (working_files[file]->analyzed && policy >= 0)
     {
         working_files_mutex.unlock();
 
-        Policy *p = mainwindow->get_policy((size_t)policy);
-        if (p)
-        {
-            std::vector<std::string> policies_names, policies_contents;
-            std::vector<MediaConchLib::ValidateRes*> res;
-            std::string policy_content;
-            p->dump_schema(policy_content);
-            policies_contents.push_back(policy_content);
+        std::vector<size_t> policies_ids;
+        std::vector<std::string> policies_contents;
+        std::vector<MediaConchLib::Checker_ValidateRes*> res;
+        std::map<std::string, std::string> options;
+        policies_ids.push_back(policy);
 
-            if (mainwindow->validate(MediaConchLib::report_Max, file,
-                                     policies_names, policies_contents, res) == 0 && res.size() == 1)
-            {
-                policy_valid = res[0]->valid;
-                for (size_t j = 0; j < res.size() ; ++j)
-                    delete res[j];
-                res.clear();
-            }
+        if (mainwindow->validate(MediaConchLib::report_Max, file,
+                                 policies_ids, policies_contents, options, res) == 0 && res.size() == 1)
+        {
+            policy_valid = res[0]->valid;
+            for (size_t j = 0; j < res.size() ; ++j)
+                delete res[j];
+            res.clear();
         }
 
         working_files_mutex.lock();
     }
 
-    working_files[file]->policy = policy;
     working_files[file]->policy_valid = policy_valid;
     FileRegistered fr = *working_files[file];
     working_files_mutex.unlock();
@@ -335,44 +407,41 @@ void WorkerFiles::update_unfinished_files()
             continue;
         }
 
-        double percent;
-
-        MediaConchLib::report report_kind;
-        int ret = mainwindow->is_analyze_finished(files[i], percent, report_kind);
+        MediaConchLib::Checker_StatusRes st_res;
+        int ret = mainwindow->is_analyze_finished(files[i], st_res);
         if (ret < 0)
         {
             mainwindow->set_error_http((MediaConchLib::errorHttp)ret);
             return;
         }
 
-        fr->analyzed = false;
-        if (ret == MediaConchLib::errorHttp_TRUE)
+        fr->analyzed = st_res.finished;
+        if (st_res.finished)
         {
-            fr->analyzed = true;
-            fr->report_kind = report_kind;
-            std::vector<std::string> policies_names, policies_contents;
-            std::vector<MediaConchLib::ValidateRes*> res;
+            fr->report_kind = MediaConchLib::report_MediaConch;
+            if (st_res.tool)
+                fr->report_kind = *st_res.tool;
 
-            if (mainwindow->validate(report_kind, files[i],
-                                     policies_names, policies_contents, res) == 0
+            std::vector<size_t> policies_ids;
+            std::vector<std::string> policies_contents;
+            std::map<std::string, std::string> options;
+            std::vector<MediaConchLib::Checker_ValidateRes*> res;
+
+            if (mainwindow->validate((MediaConchLib::report)fr->report_kind, files[i],
+                                     policies_ids, policies_contents, options, res) == 0
                 && res.size() == 1)
                 fr->implementation_valid = res[0]->valid;
 
             for (size_t j = 0; j < res.size() ; ++j)
                 delete res[j];
             res.clear();
-            if (report_kind == MediaConchLib::report_MediaConch && fr->policy >= 0)
-            {
-                Policy *p = mainwindow->get_policy((size_t)fr->policy);
-                if (p)
-                {
-                    std::string policy_content;
-                    p->dump_schema(policy_content);
-                    policies_contents.push_back(policy_content);
-                }
 
-                if (p && mainwindow->validate(MediaConchLib::report_Max, files[i],
-                                              policies_names, policies_contents, res) == 0 && res.size() == 1)
+            if (fr->report_kind == MediaConchLib::report_MediaConch && fr->policy >= 0)
+            {
+                policies_ids.push_back(fr->policy);
+
+                if (mainwindow->validate(MediaConchLib::report_Max, files[i],
+                                         policies_ids, policies_contents, options, res) == 0 && res.size() == 1)
                     fr->policy_valid = res[0]->valid;
                 for (size_t j = 0; j < res.size() ; ++j)
                     delete res[j];
@@ -381,7 +450,9 @@ void WorkerFiles::update_unfinished_files()
         }
         else
         {
-            fr->analyze_percent = percent;
+            fr->analyze_percent = 0.0;
+            if (st_res.percent)
+                fr->analyze_percent = *st_res.percent;
             vec.push_back(files[i]);
         }
 
@@ -538,8 +609,8 @@ void WorkerFiles::fill_registered_files_from_db()
         full_file += fr->filename;
 
         //check if policy still exists
-        Policy *p = mainwindow->get_policy(fr->policy);
-        if (!p)
+        MediaConchLib::Get_Policy p;
+        if (mainwindow->policy_get(fr->policy, "JSON", p) < 0)
             fr->policy = -1;
 
         fr->index = file_index++;
@@ -547,6 +618,17 @@ void WorkerFiles::fill_registered_files_from_db()
 
         working_files[full_file] = fr;
         files.push_back(full_file);
+
+
+        std::vector<std::string> tmp;
+        tmp.push_back(full_file);
+
+        int ret;
+        std::vector<long> files_id;
+        if ((ret = mainwindow->analyze(tmp, false, files_id)) < 0 && files_id.size() != 1)
+            mainwindow->set_error_http((MediaConchLib::errorHttp)ret);
+        else
+            fr->file_id = files_id[0];
     }
     working_files_mutex.unlock();
 
@@ -554,10 +636,6 @@ void WorkerFiles::fill_registered_files_from_db()
     for (size_t i = 0; i < files.size(); ++i)
         unfinished_files.push_back(files[i]);
     unfinished_files_mutex.unlock();
-
-    int ret;
-    if ((ret = mainwindow->analyze(files)) < 0)
-        mainwindow->set_error_http((MediaConchLib::errorHttp)ret);
 }
 
 }
